# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .alert_muting_rule import *
from .dashboard import *
from .dashboard_group import *
from .data_link import *
from .detector import *
from .event_feed_chart import *
from .get_dimension_values import *
from .heatmap_chart import *
from .list_chart import *
from .metric_ruleset import *
from .org_token import *
from .provider import *
from .single_value_chart import *
from .slo import *
from .table_chart import *
from .team import *
from .text_chart import *
from .time_chart import *
from .webhook_integration import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_signalfx.aws as __aws
    aws = __aws
    import pulumi_signalfx.azure as __azure
    azure = __azure
    import pulumi_signalfx.config as __config
    config = __config
    import pulumi_signalfx.gcp as __gcp
    gcp = __gcp
    import pulumi_signalfx.jira as __jira
    jira = __jira
    import pulumi_signalfx.log as __log
    log = __log
    import pulumi_signalfx.opsgenie as __opsgenie
    opsgenie = __opsgenie
    import pulumi_signalfx.pagerduty as __pagerduty
    pagerduty = __pagerduty
    import pulumi_signalfx.servicenow as __servicenow
    servicenow = __servicenow
    import pulumi_signalfx.slack as __slack
    slack = __slack
    import pulumi_signalfx.victorops as __victorops
    victorops = __victorops
else:
    aws = _utilities.lazy_import('pulumi_signalfx.aws')
    azure = _utilities.lazy_import('pulumi_signalfx.azure')
    config = _utilities.lazy_import('pulumi_signalfx.config')
    gcp = _utilities.lazy_import('pulumi_signalfx.gcp')
    jira = _utilities.lazy_import('pulumi_signalfx.jira')
    log = _utilities.lazy_import('pulumi_signalfx.log')
    opsgenie = _utilities.lazy_import('pulumi_signalfx.opsgenie')
    pagerduty = _utilities.lazy_import('pulumi_signalfx.pagerduty')
    servicenow = _utilities.lazy_import('pulumi_signalfx.servicenow')
    slack = _utilities.lazy_import('pulumi_signalfx.slack')
    victorops = _utilities.lazy_import('pulumi_signalfx.victorops')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "signalfx",
  "mod": "aws/externalIntegration",
  "fqn": "pulumi_signalfx.aws",
  "classes": {
   "signalfx:aws/externalIntegration:ExternalIntegration": "ExternalIntegration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "aws/integration",
  "fqn": "pulumi_signalfx.aws",
  "classes": {
   "signalfx:aws/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "aws/tokenIntegration",
  "fqn": "pulumi_signalfx.aws",
  "classes": {
   "signalfx:aws/tokenIntegration:TokenIntegration": "TokenIntegration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "azure/integration",
  "fqn": "pulumi_signalfx.azure",
  "classes": {
   "signalfx:azure/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "gcp/integration",
  "fqn": "pulumi_signalfx.gcp",
  "classes": {
   "signalfx:gcp/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/alertMutingRule",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/alertMutingRule:AlertMutingRule": "AlertMutingRule"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/dashboard",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/dashboardGroup",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/dashboardGroup:DashboardGroup": "DashboardGroup"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/dataLink",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/dataLink:DataLink": "DataLink"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/detector",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/detector:Detector": "Detector"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/eventFeedChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/eventFeedChart:EventFeedChart": "EventFeedChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/heatmapChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/heatmapChart:HeatmapChart": "HeatmapChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/listChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/listChart:ListChart": "ListChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/metricRuleset",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/metricRuleset:MetricRuleset": "MetricRuleset"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/orgToken",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/orgToken:OrgToken": "OrgToken"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/singleValueChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/singleValueChart:SingleValueChart": "SingleValueChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/slo",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/slo:Slo": "Slo"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/tableChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/tableChart:TableChart": "TableChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/team",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/team:Team": "Team"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/textChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/textChart:TextChart": "TextChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/timeChart",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/timeChart:TimeChart": "TimeChart"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "index/webhookIntegration",
  "fqn": "pulumi_signalfx",
  "classes": {
   "signalfx:index/webhookIntegration:WebhookIntegration": "WebhookIntegration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "jira/integration",
  "fqn": "pulumi_signalfx.jira",
  "classes": {
   "signalfx:jira/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "log/timeline",
  "fqn": "pulumi_signalfx.log",
  "classes": {
   "signalfx:log/timeline:Timeline": "Timeline"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "log/view",
  "fqn": "pulumi_signalfx.log",
  "classes": {
   "signalfx:log/view:View": "View"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "opsgenie/integration",
  "fqn": "pulumi_signalfx.opsgenie",
  "classes": {
   "signalfx:opsgenie/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "pagerduty/integration",
  "fqn": "pulumi_signalfx.pagerduty",
  "classes": {
   "signalfx:pagerduty/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "servicenow/integration",
  "fqn": "pulumi_signalfx.servicenow",
  "classes": {
   "signalfx:servicenow/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "slack/integration",
  "fqn": "pulumi_signalfx.slack",
  "classes": {
   "signalfx:slack/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "signalfx",
  "mod": "victorops/integration",
  "fqn": "pulumi_signalfx.victorops",
  "classes": {
   "signalfx:victorops/integration:Integration": "Integration"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "signalfx",
  "token": "pulumi:providers:signalfx",
  "fqn": "pulumi_signalfx",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IntegrationCustomNamespaceSyncRuleArgs',
    'IntegrationCustomNamespaceSyncRuleArgsDict',
    'IntegrationMetricStatsToSyncArgs',
    'IntegrationMetricStatsToSyncArgsDict',
    'IntegrationNamespaceSyncRuleArgs',
    'IntegrationNamespaceSyncRuleArgsDict',
]

MYPY = False

if not MYPY:
    class IntegrationCustomNamespaceSyncRuleArgsDict(TypedDict):
        namespace: pulumi.Input[str]
        """
        An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See the AWS documentation on publishing metrics for more information.
        """
        default_action: NotRequired[pulumi.Input[str]]
        """
        Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        """
        filter_action: NotRequired[pulumi.Input[str]]
        """
        Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        """
        filter_source: NotRequired[pulumi.Input[str]]
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
elif False:
    IntegrationCustomNamespaceSyncRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationCustomNamespaceSyncRuleArgs:
    def __init__(__self__, *,
                 namespace: pulumi.Input[str],
                 default_action: Optional[pulumi.Input[str]] = None,
                 filter_action: Optional[pulumi.Input[str]] = None,
                 filter_source: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] namespace: An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See the AWS documentation on publishing metrics for more information.
        :param pulumi.Input[str] default_action: Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        :param pulumi.Input[str] filter_action: Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        :param pulumi.Input[str] filter_source: Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
        pulumi.set(__self__, "namespace", namespace)
        if default_action is not None:
            pulumi.set(__self__, "default_action", default_action)
        if filter_action is not None:
            pulumi.set(__self__, "filter_action", filter_action)
        if filter_source is not None:
            pulumi.set(__self__, "filter_source", filter_source)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See the AWS documentation on publishing metrics for more information.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="defaultAction")
    def default_action(self) -> Optional[pulumi.Input[str]]:
        """
        Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        """
        return pulumi.get(self, "default_action")

    @default_action.setter
    def default_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_action", value)

    @property
    @pulumi.getter(name="filterAction")
    def filter_action(self) -> Optional[pulumi.Input[str]]:
        """
        Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        """
        return pulumi.get(self, "filter_action")

    @filter_action.setter
    def filter_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_action", value)

    @property
    @pulumi.getter(name="filterSource")
    def filter_source(self) -> Optional[pulumi.Input[str]]:
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
        return pulumi.get(self, "filter_source")

    @filter_source.setter
    def filter_source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_source", value)


if not MYPY:
    class IntegrationMetricStatsToSyncArgsDict(TypedDict):
        metric: pulumi.Input[str]
        """
        AWS metric that you want to pick statistics for
        """
        namespace: pulumi.Input[str]
        """
        An AWS namespace having AWS metric that you want to pick statistics for
        """
        stats: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        AWS statistics you want to collect
        """
elif False:
    IntegrationMetricStatsToSyncArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationMetricStatsToSyncArgs:
    def __init__(__self__, *,
                 metric: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 stats: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[str] metric: AWS metric that you want to pick statistics for
        :param pulumi.Input[str] namespace: An AWS namespace having AWS metric that you want to pick statistics for
        :param pulumi.Input[Sequence[pulumi.Input[str]]] stats: AWS statistics you want to collect
        """
        pulumi.set(__self__, "metric", metric)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "stats", stats)

    @property
    @pulumi.getter
    def metric(self) -> pulumi.Input[str]:
        """
        AWS metric that you want to pick statistics for
        """
        return pulumi.get(self, "metric")

    @metric.setter
    def metric(self, value: pulumi.Input[str]):
        pulumi.set(self, "metric", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        An AWS namespace having AWS metric that you want to pick statistics for
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def stats(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        AWS statistics you want to collect
        """
        return pulumi.get(self, "stats")

    @stats.setter
    def stats(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "stats", value)


if not MYPY:
    class IntegrationNamespaceSyncRuleArgsDict(TypedDict):
        namespace: pulumi.Input[str]
        """
        An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See `services` field description below for additional information.
        """
        default_action: NotRequired[pulumi.Input[str]]
        """
        Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        """
        filter_action: NotRequired[pulumi.Input[str]]
        """
        Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        """
        filter_source: NotRequired[pulumi.Input[str]]
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
elif False:
    IntegrationNamespaceSyncRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationNamespaceSyncRuleArgs:
    def __init__(__self__, *,
                 namespace: pulumi.Input[str],
                 default_action: Optional[pulumi.Input[str]] = None,
                 filter_action: Optional[pulumi.Input[str]] = None,
                 filter_source: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] namespace: An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See `services` field description below for additional information.
        :param pulumi.Input[str] default_action: Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        :param pulumi.Input[str] filter_action: Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        :param pulumi.Input[str] filter_source: Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
        pulumi.set(__self__, "namespace", namespace)
        if default_action is not None:
            pulumi.set(__self__, "default_action", default_action)
        if filter_action is not None:
            pulumi.set(__self__, "filter_action", filter_action)
        if filter_source is not None:
            pulumi.set(__self__, "filter_source", filter_source)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        An AWS custom namespace having custom AWS metrics that you want to sync with Splunk Observability Cloud. See `services` field description below for additional information.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="defaultAction")
    def default_action(self) -> Optional[pulumi.Input[str]]:
        """
        Controls the Splunk Observability Cloud default behavior for processing data from an AWS namespace. Splunk Observability Cloud ignores this property unless you specify the `filter_action` and `filter_source` properties. If you do specify them, use this property to control how Splunk Observability Cloud treats data that doesn't match the filter. The available actions are one of `"Include"` or `"Exclude"`.
        """
        return pulumi.get(self, "default_action")

    @default_action.setter
    def default_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_action", value)

    @property
    @pulumi.getter(name="filterAction")
    def filter_action(self) -> Optional[pulumi.Input[str]]:
        """
        Controls how Splunk Observability Cloud processes data from a custom AWS namespace. The available actions are one of `"Include"` or `"Exclude"`.
        """
        return pulumi.get(self, "filter_action")

    @filter_action.setter
    def filter_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_action", value)

    @property
    @pulumi.getter(name="filterSource")
    def filter_source(self) -> Optional[pulumi.Input[str]]:
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the custom namespace associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function; it can be any valid SignalFlow filter expression.
        """
        return pulumi.get(self, "filter_source")

    @filter_source.setter
    def filter_source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_source", value)


